@@ -1,9 +1,9 @@
 from typing import Optional, Dict, List, Any
-from notion_client import Client
 import pandas as pd
 import os
 import requests
 import mimetypes
+import json
 
 # NotionHelper can be used in conjunction with the Streamlit APP: (Notion API JSON)[https://notioinapiassistant.streamlit.app]
 
@@ -17,35 +17,38 @@ class NotionHelper:
     __init__():
         Initializes the NotionHelper instance and authenticates with the Notion API.
 
-    authenticate():
-        Authenticates with the Notion API using a token from environment variables.
+    _make_request(method, url, payload=None, api_version="2025-09-03"):
+        Internal helper to make authenticated requests to the Notion API.
 
     get_database(database_id):
-        Fetches the schema of a Notion database given its database_id.
+        Retrieves the database object, which contains a list of data sources.
 
-    notion_search_db(database_id, query=""):
-        Searches for pages in a Notion database that contain the specified query in their title.
+    get_data_source(data_source_id):
+        Retrieves a specific data source, including its properties (schema).
+
+    notion_search_db(query="", filter_object_type="page"):
+        Searches for pages or data sources in Notion.
 
     notion_get_page(page_id):
         Returns the JSON of the page properties and an array of blocks on a Notion page given its page_id.
 
-    create_database(parent_page_id, database_title, properties):
-        Creates a new database in Notion under the specified parent page with the given title and properties.
+    create_database(parent_page_id, database_title, initial_data_source_properties, initial_data_source_title=None):
+        Creates a new database in Notion with an initial data source.
 
-    new_page_to_db(database_id, page_properties):
-        Adds a new page to a Notion database with the specified properties.
+    new_page_to_db(data_source_id, page_properties):
+        Adds a new page to a Notion data source with the specified properties.
 
     append_page_body(page_id, blocks):
         Appends blocks of text to the body of a Notion page.
 
-    get_all_page_ids(database_id):
-        Returns the IDs of all pages in a given Notion database.
+    get_all_page_ids(data_source_id):
+        Returns the IDs of all pages in a given Notion data source.
 
-    get_all_pages_as_json(database_id, limit=None):
-        Returns a list of JSON objects representing all pages in the given database, with all properties.
+    get_all_pages_as_json(data_source_id, limit=None):
+        Returns a list of JSON objects representing all pages in the given data source, with all properties.
 
-    get_all_pages_as_dataframe(database_id, limit=None):
-        Returns a Pandas DataFrame representing all pages in the given database, with selected properties.
+    get_all_pages_as_dataframe(data_source_id, limit=None):
+        Returns a Pandas DataFrame representing all pages in the given data source, with selected properties.
 
     upload_file(file_path):
         Uploads a file to Notion and returns the file upload object.
@@ -58,16 +61,55 @@ class NotionHelper:
 
     attach_file_to_page_property(page_id, property_name, file_upload_id, file_name):
         Attaches a file to a Files & Media property on a specific page.
+
+    update_data_source(data_source_id, properties=None, title=None, icon=None, in_trash=None, parent=None):
+        Updates the attributes of a specified data source.
     """
 
     def __init__(self, notion_token: str):
-        """Initializes the NotionHelper instance and authenticates with the Notion API
-        using the provided token."""
+        """Initializes the NotionHelper instance with the provided token."""
         self.notion_token = notion_token
-        self.notion = Client(auth=self.notion_token)
+
+    def _make_request(self, method: str, url: str, payload: Optional[Dict[str, Any]] = None, api_version: str = "2025-09-03") -> Dict[str, Any]:
+        """
+        Internal helper to make authenticated requests to the Notion API.
+        Handles headers, JSON serialization, and error checking.
+        """
+        headers = {
+            "Authorization": f"Bearer {self.notion_token}",
+            "Content-Type": "application/json",
+            "Notion-Version": api_version,
+        }
+        response = None  # Initialize response to None
+        try:
+            if method == "GET":
+                response = requests.get(url, headers=headers)
+            elif method == "POST":
+                response = requests.post(url, headers=headers, data=json.dumps(payload))
+            elif method == "PATCH":
+                response = requests.patch(url, headers=headers, data=json.dumps(payload))
+            else:
+                raise ValueError(f"Unsupported HTTP method: {method}")
+
+            response.raise_for_status()  # Raise an exception for HTTP errors
+            return response.json()
+        except requests.exceptions.HTTPError as http_err:
+            print(f"HTTP error occurred: {http_err}")
+            if response is not None:  # Check if response was assigned before accessing .text
+                print(f"Response Body: {response.text}")
+            raise
+        except requests.exceptions.RequestException as req_err:
+            print(f"Request error occurred: {req_err}")
+            raise
+        except Exception as e:
+            print(f"An unexpected error occurred: {e}")
+            raise
 
     def get_database(self, database_id: str) -> Dict[str, Any]:
         """Retrieves the schema of a Notion database given its database_id.
+        With API version 2025-09-03, this now returns the database object
+        which contains a list of data sources. To get the actual schema (properties),
+        you need to retrieve a specific data source.
 
         Parameters
         ----------
@@ -77,52 +119,67 @@ class NotionHelper:
         Returns
         -------
         dict
-            A dictionary representing the database schema.
+            A dictionary representing the database object, including its data sources.
         """
-        try:
-            response = self.notion.databases.retrieve(database_id=database_id)
-            return response
-        except Exception as e:
-            raise Exception(f"Failed to retrieve database {database_id}: {str(e)}")
+        url = f"https://api.notion.com/v1/databases/{database_id}"
+        return self._make_request("GET", url)
 
-    def notion_search_db(
-        self, database_id: str, query: str = ""
-    ) -> None:
-        """Searches for pages in a Notion database that contain the specified query in their title."""
-        my_pages = self.notion.databases.query(
-            database_id=database_id,
-            filter={
-                "property": "title",
-                "rich_text": {"contains": query},
-            },
-        )
+    def get_data_source(self, data_source_id: str) -> Dict[str, Any]:
+        """Retrieves a specific data source given its data_source_id.
+        This is used to get the schema (properties) of a data source.
 
-        page_title = my_pages["results"][0]["properties"]["Code / Notebook Description"]["title"][0]["plain_text"]
-        page_url = my_pages["results"][0]["url"]
+        Parameters
+        ----------
+        data_source_id : str
+            The unique identifier of the Notion data source.
 
-        page_list = my_pages["results"]
-        count = 1
-        for page in page_list:
-            try:
-                print(
-                    count,
-                    page["properties"]["Code / Notebook Description"]["title"][0]["plain_text"],
-                )
-            except IndexError:
-                print("No results found.")
+        Returns
+        -------
+        dict
+            A dictionary representing the data source object, including its properties.
+        """
+        url = f"https://api.notion.com/v1/data_sources/{data_source_id}"
+        return self._make_request("GET", url)
 
-            print(page["url"])
-            print()
-            count += 1
+    def notion_search_db(self, query: str = "", filter_object_type: str = "page") -> List[Dict[str, Any]]:
+        """Searches for pages or data sources in Notion.
 
-        # pprint.pprint(page)
+        Parameters
+        ----------
+        query : str
+            The search query.
+        filter_object_type : str
+            The type of object to filter by. Can be "page" or "data_source".
 
-    def notion_get_page(self, page_id: str) -> Dict[str, Any]:
+        Returns
+        -------
+        List[Dict[str, Any]]
+            A list of dictionaries representing the search results.
+        """
+        if filter_object_type not in ["page", "data_source"]:
+            raise ValueError("filter_object_type must be 'page' or 'data_source'")
+
+        url = "https://api.notion.com/v1/search"
+        payload = {
+            "query": query,
+            "filter": {
+                "value": filter_object_type,
+                "property": "object"
+            }
+        }
+        response = self._make_request("POST", url, payload)
+        return response.get("results", [])
+
+    def get_page(self, page_id: str) -> Dict[str, Any]:
         """Retrieves the JSON of the page properties and an array of blocks on a Notion page given its page_id."""
 
-        # Retrieve the page and block data
-        page = self.notion.pages.retrieve(page_id)
-        blocks = self.notion.blocks.children.list(page_id)
+        # Retrieve the page properties
+        page_url = f"https://api.notion.com/v1/pages/{page_id}"
+        page = self._make_request("GET", page_url)
+
+        # Retrieve the block data (content)
+        blocks_url = f"https://api.notion.com/v1/blocks/{page_id}/children"
+        blocks = self._make_request("GET", blocks_url)
 
         # Extract all properties as a JSON object
         properties = page.get("properties", {})
@@ -134,78 +191,145 @@ class NotionHelper:
         # Return the properties JSON and blocks content
         return {"properties": properties, "content": content}
 
-    def create_database(self, parent_page_id: str, database_title: str, properties: Dict[str, Any]) -> Dict[str, Any]:
-        """Creates a new database in Notion.
+    def create_database(self, parent_page_id: str, database_title: str, initial_data_source_properties: Dict[str, Any], initial_data_source_title: Optional[str] = None) -> Dict[str, Any]:
+        """Creates a new database in Notion with an initial data source.
 
-        This method creates a new database under a specified parent page with the provided title and property definitions.
+        This method creates a new database under a specified parent page with the provided title
+        and defines the schema for its initial data source.
 
         Parameters:
             parent_page_id (str): The unique identifier of the parent page.
-            database_title (str): The title for the new database.
-            properties (dict): A dictionary defining the property schema for the database.
+            database_title (str): The title for the new database container.
+            initial_data_source_properties (dict): A dictionary defining the property schema for the initial data source.
+            initial_data_source_title (str, optional): The title for the initial data source. Defaults to database_title.
 
         Returns:
-            dict: The JSON response from the Notion API containing details about the created database.
-        """
+            dict: The JSON response from the Notion API containing details about the created database and its initial data source.
 
-        # Define the properties for the database
-        new_database = {
+        Example JSON p[ayload:
+            properties = {
+                "Mandatory Title": {"title": {}},
+                "Description": {"rich_text": {}}
+            }
+        """
+        if initial_data_source_title is None:
+            initial_data_source_title = database_title
+
+        payload = {
             "parent": {"type": "page_id", "page_id": parent_page_id},
             "title": [{"type": "text", "text": {"content": database_title}}],
-            "properties": properties,
+            "initial_data_source": {
+                "title": [{"type": "text", "text": {"content": initial_data_source_title}}],
+                "properties": initial_data_source_properties,
+            },
         }
+        url = "https://api.notion.com/v1/databases"
+        return self._make_request("POST", url, payload)
 
-        response = self.notion.databases.create(**new_database)
-        return response
+    def update_data_source(self, data_source_id: str, properties: Optional[Dict[str, Any]] = None, title: Optional[List[Dict[str, Any]]] = None, icon: Optional[Dict[str, Any]] = None, in_trash: Optional[bool] = None, parent: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
+        """Updates the attributes of a specified data source.
 
-    def new_page_to_db(self, database_id: str, page_properties: Dict[str, Any]) -> Dict[str, Any]:
-        """Adds a new page to a Notion database."""
+        Parameters:
+            data_source_id (str): The unique identifier of the Notion data source to update.
+            properties (dict, optional): A dictionary defining the property schema updates for the data source.
+                                         Use `{"Property Name": null}` to remove a property.
+                                         Use `{"Old Name": {"name": "New Name"}}` to rename.
+                                         Use `{"New Property": {"type": "rich_text", "rich_text": {}}}` to add.
+            title (list, optional): The new title for the data source.
+            icon (dict, optional): The new icon for the data source.
+            in_trash (bool, optional): Whether to move the data source to or from the trash.
+            parent (dict, optional): The new parent database if moving the data source.
 
-        new_page = {
-            "parent": {"database_id": database_id},
+        Returns:
+            dict: The JSON response from the Notion API containing details about the updated data source.
+        """
+        payload = {}
+        if properties is not None:
+            payload["properties"] = properties
+        if title is not None:
+            payload["title"] = title
+        if icon is not None:
+            payload["icon"] = icon
+        if in_trash is not None:
+            payload["in_trash"] = in_trash
+        if parent is not None:
+            payload["parent"] = parent
+
+        if not payload:
+            raise ValueError("No update parameters provided. Please provide at least one of: properties, title, icon, in_trash, parent.")
+
+        url = f"https://api.notion.com/v1/data_sources/{data_source_id}"
+        return self._make_request("PATCH", url, payload)
+
+    def new_page_to_data_source(self, data_source_id: str, page_properties: Dict[str, Any]) -> Dict[str, Any]:
+        """Adds a new page to a Notion data source.
+        With API version 2025-09-03, pages are parented by data_source_id, not database_id.
+
+        Parameters:
+            data_source_id (str): The unique identifier of the Notion data source.
+            page_properties (dict): A dictionary defining the properties for the new page.
+
+        Returns:
+            dict: The JSON response from the Notion API containing details about the created page.
+        """
+        payload = {
+            "parent": {"data_source_id": data_source_id},
             "properties": page_properties,
         }
-
-        response = self.notion.pages.create(**new_page)
-        return response
+        url = "https://api.notion.com/v1/pages"
+        return self._make_request("POST", url, payload)
 
     def append_page_body(self, page_id: str, blocks: List[Dict[str, Any]]) -> Dict[str, Any]:
         """Appends blocks of text to the body of a Notion page."""
+        payload = {"children": blocks}
+        url = f"https://api.notion.com/v1/blocks/{page_id}/children"
+        return self._make_request("PATCH", url, payload)
 
-        new_blocks = {"children": blocks}
+    def get_data_source_page_ids(self, data_source_id: str) -> List[str]:
+        """Returns the IDs of all pages in a given data source.
+        With API version 2025-09-03, this queries a data source, not a database.
+        """
+        url = f"https://api.notion.com/v1/data_sources/{data_source_id}/query"
+        pages_json = []
+        has_more = True
+        start_cursor = None
 
-        response = self.notion.blocks.children.append(block_id=page_id, **new_blocks)
-        return response
+        while has_more:
+            payload = {}
+            if start_cursor:
+                payload["start_cursor"] = start_cursor
 
-    def get_all_page_ids(self, database_id: str) -> List[str]:
-        """Returns the IDs of all pages in a given database."""
+            response = self._make_request("POST", url, payload)
+            pages_json.extend(response["results"])
+            has_more = response.get("has_more", False)
+            start_cursor = response.get("next_cursor", None)
 
-        my_pages = self.notion.databases.query(database_id=database_id)
-        page_ids = [page["id"] for page in my_pages["results"]]
+        page_ids = [page["id"] for page in pages_json]
         return page_ids
 
-    def get_all_pages_as_json(self, database_id: str, limit: Optional[int] = None) -> List[Dict[str, Any]]:
-        """Returns a list of JSON objects representing all pages in the given database, with all properties.
+    def get_data_source_pages_as_json(self, data_source_id: str, limit: Optional[int] = None) -> List[Dict[str, Any]]:
+        """Returns a list of JSON objects representing all pages in the given data source, with all properties.
         You can specify the number of entries to be loaded using the `limit` parameter.
+        With API version 2025-09-03, this queries a data source, not a database.
         """
-
-        # Use pagination to remove any limits on number of entries, optionally limited by `limit` argument
+        url = f"https://api.notion.com/v1/data_sources/{data_source_id}/query"
         pages_json = []
         has_more = True
         start_cursor = None
         count = 0
 
         while has_more:
-            my_pages = self.notion.databases.query(
-                **{
-                    "database_id": database_id,
-                    "start_cursor": start_cursor,
-                }
-            )
-            pages_json.extend([page["properties"] for page in my_pages["results"]])
-            has_more = my_pages.get("has_more", False)
-            start_cursor = my_pages.get("next_cursor", None)
-            count += len(my_pages["results"])
+            payload = {}
+            if start_cursor:
+                payload["start_cursor"] = start_cursor
+            if limit is not None:
+                payload["page_size"] = min(100, limit - count) # Max page size is 100
+
+            response = self._make_request("POST", url, payload)
+            pages_json.extend([page["properties"] for page in response["results"]])
+            has_more = response.get("has_more", False)
+            start_cursor = response.get("next_cursor", None)
+            count += len(response["results"])
 
             if limit is not None and count >= limit:
                 pages_json = pages_json[:limit]
@@ -213,15 +337,15 @@ class NotionHelper:
 
         return pages_json
 
-    def get_all_pages_as_dataframe(self, database_id: str, limit: Optional[int] = None, include_page_ids: bool = True) -> pd.DataFrame:
-        """Retrieves all pages from a Notion database and returns them as a Pandas DataFrame.
+    def get_data_source_pages_as_dataframe(self, data_source_id: str, limit: Optional[int] = None, include_page_ids: bool = True) -> pd.DataFrame:
+        """Retrieves all pages from a Notion data source and returns them as a Pandas DataFrame.
 
-        This method collects pages from the specified Notion database, optionally including the page IDs,
+        This method collects pages from the specified Notion data source, optionally including the page IDs,
         and extracts a predefined set of allowed properties from each page to form a structured DataFrame.
         Numeric values are formatted to avoid scientific notation.
 
         Parameters:
-            database_id (str): The identifier of the Notion database.
+            data_source_id (str): The identifier of the Notion data source.
             limit (int, optional): Maximum number of page entries to include. If None, all pages are retrieved.
             include_page_ids (bool, optional): If True, includes an additional column 'notion_page_id' in the DataFrame.
                                                Defaults to True.
@@ -231,29 +355,34 @@ class NotionHelper:
                               If include_page_ids is True, an additional column 'notion_page_id' is included.
         """
         # Retrieve pages with or without page IDs based on the flag
-        if include_page_ids:
-            pages_json = []
-            has_more = True
-            start_cursor = None
-            count = 0
-            # Retrieve pages with pagination including the page ID in properties
-            while has_more:
-                my_pages = self.notion.databases.query(
-                    database_id=database_id,
-                    start_cursor=start_cursor,
-                )
-                for page in my_pages["results"]:
-                    props = page["properties"]
+        all_pages_data = []
+        has_more = True
+        start_cursor = None
+        count = 0
+
+        url = f"https://api.notion.com/v1/data_sources/{data_source_id}/query"
+
+        while has_more:
+            payload = {}
+            if start_cursor:
+                payload["start_cursor"] = start_cursor
+            if limit is not None:
+                payload["page_size"] = min(100, limit - count) # Max page size is 100
+
+            response = self._make_request("POST", url, payload)
+            for page in response["results"]:
+                props = page["properties"]
+                if include_page_ids:
                     props["notion_page_id"] = page.get("id", "")
-                    pages_json.append(props)
-                has_more = my_pages.get("has_more", False)
-                start_cursor = my_pages.get("next_cursor", None)
-                count += len(my_pages["results"])
-                if limit is not None and count >= limit:
-                    pages_json = pages_json[:limit]
-                    break
-        else:
-            pages_json = self.get_all_pages_as_json(database_id, limit=limit)
+                all_pages_data.append(props)
+
+            has_more = response.get("has_more", False)
+            start_cursor = response.get("next_cursor", None)
+            count += len(response["results"])
+
+            if limit is not None and count >= limit:
+                all_pages_data = all_pages_data[:limit]
+                break
 
         data = []
         # Define the list of allowed property types that we want to extract
@@ -282,7 +411,7 @@ class NotionHelper:
         if include_page_ids:
             allowed_properties.append("notion_page_id")
 
-        for page in pages_json:
+        for page in all_pages_data:
             row = {}
             for key, value in page.items():
                 if key == "notion_page_id":
@@ -354,26 +483,23 @@ class NotionHelper:
         """Uploads a file to Notion and returns the file upload object."""
         if not os.path.exists(file_path):
             raise FileNotFoundError(f"File not found: {file_path}")
-            
+
         try:
             # Step 1: Create a File Upload object
             create_upload_url = "https://api.notion.com/v1/file_uploads"
-            headers = {
+            # File uploads still use the older API version
+            upload_headers = {
                 "Authorization": f"Bearer {self.notion_token}",
                 "Content-Type": "application/json",
                 "Notion-Version": "2022-06-28",
             }
-            response = requests.post(create_upload_url, headers=headers, json={})
+            response = requests.post(create_upload_url, headers=upload_headers, json={})
             response.raise_for_status()
             upload_data = response.json()
             upload_url = upload_data["upload_url"]
 
             # Step 2: Upload file contents
             with open(file_path, "rb") as f:
-                upload_headers = {
-                    "Authorization": f"Bearer {self.notion_token}",
-                    "Notion-Version": "2022-06-28",
-                }
                 files = {'file': (os.path.basename(file_path), f, mimetypes.guess_type(file_path)[0] or 'application/octet-stream')}
                 upload_response = requests.post(upload_url, headers=upload_headers, files=files)
                 upload_response.raise_for_status()
@@ -386,13 +512,7 @@ class NotionHelper:
 
     def attach_file_to_page(self, page_id: str, file_upload_id: str) -> Dict[str, Any]:
         """Attaches an uploaded file to a specific page."""
-        attach_url = f"https://api.notion.com/v1/blocks/{page_id}/children"
-        headers = {
-            "Authorization": f"Bearer {self.notion_token}",
-            "Content-Type": "application/json",
-            "Notion-Version": "2022-06-28",
-        }
-        data = {
+        payload = {
             "children": [
                 {
                     "type": "file",
@@ -405,18 +525,12 @@ class NotionHelper:
                 }
             ]
         }
-        response = requests.patch(attach_url, headers=headers, json=data)
-        return response.json()
+        url = f"https://api.notion.com/v1/blocks/{page_id}/children"
+        return self._make_request("PATCH", url, payload)
 
     def embed_image_to_page(self, page_id: str, file_upload_id: str) -> Dict[str, Any]:
         """Embeds an uploaded image to a specific page."""
-        attach_url = f"https://api.notion.com/v1/blocks/{page_id}/children"
-        headers = {
-            "Authorization": f"Bearer {self.notion_token}",
-            "Content-Type": "application/json",
-            "Notion-Version": "2022-06-28",
-        }
-        data = {
+        payload = {
             "children": [
                 {
                     "type": "image",
@@ -429,20 +543,14 @@ class NotionHelper:
                 }
             ]
         }
-        response = requests.patch(attach_url, headers=headers, json=data)
-        return response.json()
+        url = f"https://api.notion.com/v1/blocks/{page_id}/children"
+        return self._make_request("PATCH", url, payload)
 
     def attach_file_to_page_property(
         self, page_id: str, property_name: str, file_upload_id: str, file_name: str
     ) -> Dict[str, Any]:
         """Attaches a file to a Files & Media property on a specific page."""
-        update_url = f"https://api.notion.com/v1/pages/{page_id}"
-        headers = {
-            "Authorization": f"Bearer {self.notion_token}",
-            "Content-Type": "application/json",
-            "Notion-Version": "2022-06-28",
-        }
-        data = {
+        payload = {
             "properties": {
                 property_name: {
                     "files": [
@@ -455,8 +563,8 @@ class NotionHelper:
                 }
             }
         }
-        response = requests.patch(update_url, headers=headers, json=data)
-        return response.json()
+        url = f"https://api.notion.com/v1/pages/{page_id}"
+        return self._make_request("PATCH", url, payload)
 
     def one_step_image_embed(self, page_id: str, file_path: str) -> Dict[str, Any]:
         """Uploads an image and embeds it in a Notion page in one step."""
@@ -487,60 +595,3 @@ class NotionHelper:
 
         # Attach the file to the page property
         return self.attach_file_to_page_property(page_id, property_name, file_upload_id, file_name)
-
-    def info(self) -> Optional[Any]:
-        """Displays comprehensive library information in a Jupyter notebook.
-
-        Shows:
-        - Library name and description
-        - Complete list of all available methods with descriptions
-        - Version information
-        - Optional logo display (if available)
-
-        Returns:
-            IPython.display.HTML: An HTML display object or None if IPython is not available.
-        """
-        try:
-            from IPython.display import HTML
-            import base64
-            import inspect
-
-            # Get logo image data
-            logo_path = os.path.join(os.path.dirname(__file__), '../images/helper_logo.png')
-            if os.path.exists(logo_path):
-                with open(logo_path, "rb") as image_file:
-                    encoded_logo = base64.b64encode(image_file.read()).decode('utf-8')
-            else:
-                encoded_logo = ""
-
-            # Get all methods and their docstrings
-            methods = []
-            for name, method in inspect.getmembers(self, predicate=inspect.ismethod):
-                if not name.startswith('_'):
-                    doc = inspect.getdoc(method) or "No description available"
-                    methods.append(f"<li><code>{name}()</code>: {doc.splitlines()[0]}</li>")
-
-            # Create HTML content
-            html_content = f"""
-            <div style="font-family: 'Inter', -apple-system, BlinkMacSystemFont, sans-serif; max-width: 800px; margin: 0 auto; color: #1e293b;">
-                <h1 style="color: #1e293b;">NotionHelper Library</h1>
-                {f'<img src="data:image/png;base64,{encoded_logo}" style="max-width: 200px; margin: 20px 0; display: block;">' if encoded_logo else ''}
-                <p style="font-size: 1.1rem;">A Python helper class for interacting with the Notion API.</p>
-                <h3 style="color: #1e293b;">All Available Methods:</h3>
-                <ul style="list-style-type: none; padding-left: 0;">
-                    {''.join(methods)}
-                </ul>
-                <h3 style="color: #1e293b;">Features:</h3>
-                <ul style="list-style-type: none; padding-left: 0;">
-                    <li style="margin-bottom: 8px;">Database querying and manipulation</li>
-                    <li style="margin-bottom: 8px;">Page creation and editing</li>
-                    <li style="margin-bottom: 8px;">File uploads and attachments</li>
-                    <li style="margin-bottom: 8px;">Data conversion to Pandas DataFrames</li>
-                </ul>
-                <p style="font-size: 0.9rem; color: #64748b;">Version: {getattr(self, '__version__', '1.0.0')}</p>
-            </div>
-            """
-            return HTML(html_content)
-        except ImportError:
-            print("IPython is required for this functionality. Please install it with: pip install ipython")
-            return None
